==> openshift-model-machine-5.10.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineListBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineListBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.MachineListFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.MachineList,io.fabric8.openshift.api.model.machine.v1beta1.MachineListBuilder>{
  public MachineListBuilder() {
    this(false);
  }
  public MachineListBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineList(), validationEnabled);
  }
  public MachineListBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineListFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineListBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineList(), validationEnabled);
  }
  public MachineListBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineListFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineList instance) {
    this(fluent, instance, false);
  }
  public MachineListBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineListFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineListBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineList instance) {
    this(instance,false);
  }
  public MachineListBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.MachineListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineList build() {
    MachineList buildable = new MachineList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineListBuilder that = (MachineListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.3.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineListBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineListBuilder extends MachineListFluentImpl<MachineListBuilder> implements VisitableBuilder<MachineList,MachineListBuilder>{
  public MachineListBuilder() {
    this(false);
  }
  public MachineListBuilder(Boolean validationEnabled) {
    this(new MachineList(), validationEnabled);
  }
  public MachineListBuilder(MachineListFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineListBuilder(MachineListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineList(), validationEnabled);
  }
  public MachineListBuilder(MachineListFluent<?> fluent,MachineList instance) {
    this(fluent, instance, false);
  }
  public MachineListBuilder(MachineListFluent<?> fluent,MachineList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineListBuilder(MachineList instance) {
    this(instance,false);
  }
  public MachineListBuilder(MachineList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineListFluent<?> fluent;
  Boolean validationEnabled;
  public MachineList build() {
    MachineList buildable = new MachineList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
